# Examples

```{include} ../../../examples/README.md
:start-after: <!-- docs:guides-examples:start -->
:end-before: <!-- docs:guides-examples:end -->
```

## Related documentation

- {doc}`../getting-started/quickstart`
- {doc}`pipeline-authoring`
- {doc}`../api/operations`
